# ServiceX Client Library


[![GitHub Actions Status](https://github.com/ssl-hep/ServiceX_frontend/workflows/CI/CD/badge.svg?branch=master)](https://github.com/ssl-hep/ServiceX_frontend/actions)
[![Code Coverage](https://codecov.io/gh/ssl-hep/ServiceX_frontend/graph/badge.svg)](https://codecov.io/gh/ssl-hep/ServiceX_frontend)

[![PyPI version](https://badge.fury.io/py/servicex.svg)](https://badge.fury.io/py/servicex)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/servicex.svg)](https://pypi.org/project/servicex/)

[![Docs](https://readthedocs.org/projects/docs/badge/?version=latest)](https://servicex-frontend.readthedocs.io)


Python SDK and CLI Client for ServiceX

## Documentation
The development documentation is hosted at https://servicex-frontend.readthedocs.io


